@@ -57,7 +57,7 @@ class API(object):
         retry_strategy = Retry(
             total=retry_count,
             status_forcelist=[408, 429, 500, 502, 503, 504],
-            method_whitelist=["GET", "POST", "PATCH", "PUT", "DELETE"],
+            allowed_methods=["GET", "POST", "PATCH", "PUT", "DELETE"],
             backoff_factor=0.3,
             raise_on_status=False
         )
