@@ -16,3 +16,11 @@ class NotFound(CorvaException):
 
 class Forbidden(CorvaException):
     pass
+
+
+class MissingConfigError(Exception):
+    pass
+
+
+class EventFormatError(Exception):
+    pass
