@@ -60,8 +60,60 @@ class LoggingMixin(object):
         if not asset_id_check:
             return
 
-        self.log(asset_id, text)
+        self.log(asset_id, method, text)
 
     @staticmethod
-    def log(asset_id, text):
-        print(datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f"), 'asset_id_{} -> {}'.format(asset_id, text))
+    def log(asset_id, method="LOG", text=""):
+        if not method:
+            method = "LOG"
+
+        utc_time = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")
+        print(f"{utc_time} | {method.upper()} | asset_id_{asset_id} | {text}")
+
+
+class Logger:
+    logger = None
+    asset_id = None
+
+    @classmethod
+    def set_asset_id(cls, asset_id):
+        cls.asset_id = asset_id
+
+    @classmethod
+    def get_logger(cls):
+        if cls.logger is None:
+            cls.logger = LoggingMixin()
+
+        return cls.logger
+
+    @classmethod
+    def all(cls, text):
+        cls.get_logger().call('all', cls.asset_id, text)
+
+    @classmethod
+    def debug(cls, text):
+        cls.get_logger().call('debug', cls.asset_id, text)
+
+    @classmethod
+    def info(cls, text):
+        cls.get_logger().call('info', cls.asset_id, text)
+
+    @classmethod
+    def warn(cls, text):
+        cls.get_logger().call('warn', cls.asset_id, text)
+
+    @classmethod
+    def error(cls, text):
+        cls.get_logger().call('error', cls.asset_id, text)
+
+    @classmethod
+    def fatal(cls, text):
+        cls.get_logger().call('fatal', cls.asset_id, text)
+
+    @classmethod
+    def off(cls, asset_id, text):
+        pass
+
+    @classmethod
+    def log(cls, text):
+        cls.get_logger().log(cls.asset_id, "LOG", text)
