@@ -1,6 +1,7 @@
 import json
+import traceback
 
-from worker.state.mixins import StateMixin
+from worker.state.mixins import RedisMixin
 
 
 def file_to_json(file_name):
@@ -9,20 +10,20 @@ def file_to_json(file_name):
         return _json
 
 
-def get_last_processed_timestamp(asset_id: int, state_key: str, state_storage_type=None):
+def get_last_processed_timestamp(asset_id: int, state_key: str):
     """
     Get the last_processed_timestamp from state storage
     :param asset_id:
     :param state_key:
-    :param state_storage_type:
     """
     try:
-        state_app = StateMixin(state_storage_type)
+        state_app = RedisMixin()
         state_app.asset_id = asset_id
-        previous_state = state_app.load_state(state_key=state_key, auto_migrate=False)
+        previous_state = state_app.load_state(state_key=state_key)
         return previous_state.get('last_processed_timestamp', None)
-    except Exception as ex:
-        print(f"Error occurred while reading state from {state_storage_type}!\nError: {ex}")
+    except Exception:
+        print("Error occurred while reading state from Redis!")
+        traceback.print_exc()
 
     return None
 
