@@ -99,6 +99,37 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None)
 
     casing_outer_diameter = casingstring.get("data", {}).get("outer_diameter")
     casing_inner_diameter = casingstring.get("data", {}).get("inner_diameter")
+    casing_top_depth = casingstring.get("data", {}).get("top_depth")
+    casing_bottom_depth = casingstring.get("data", {}).get("bottom_depth")
+    casing_linear_weight = casingstring.get("data", {}).get("linear_weight")
+    casing_components = casingstring.get("data", {}).get("components")
+
+    # For best results in running a casing/liner in the well, the components should be presented.
+    # If not we create an alternative.
+    if not casing_components:
+        # If it is a casing that reaches to the surface, we can use the provided information on the top to construct a casing string.
+        casing_components = [
+            {
+                "family": "casing_joints",
+                "linear_weight": casing_linear_weight,
+                "length": casing_bottom_depth - casing_top_depth,
+                "outer_diameter": casing_outer_diameter,
+                "inner_diameter": casing_inner_diameter
+            }
+        ]
+        # For liners, we use the top components for the casing joint part of the liner.
+        # From the surface to the liner hanger, we create the same component with the family of DP (it is not the actual casing part and will be removed later).
+        if casing_top_depth > Wellbore.DEPTH_THRESHOLD:
+            add_component = {
+                "family": "dp",
+                "linear_weight": casing_linear_weight,
+                "length": casing_top_depth,
+                "outer_diameter": casing_outer_diameter,
+                "inner_diameter": casing_inner_diameter
+            }
+            casing_components.insert(0, add_component)
+
+        casingstring['data']['components'] = casing_components
 
     # setting active drillstring
     casingstring = Drillstring(casingstring)
